<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "(De-)Aktivierung des Adressbuches fehlgeschlagen",
"id is not set." => "ID ist nicht angegeben.",
"Cannot update addressbook with an empty name." => "Das Adressbuch kann nicht mit einem leeren Namen aktualisiert werden.",
"No ID provided" => "Keine ID angegeben",
"Error setting checksum." => "Fehler beim Setzen der Prüfsumme.",
"No categories selected for deletion." => "Keine Kategorien zum Löschen ausgewählt.",
"No address books found." => "Keine Adressbücher gefunden.",
"No contacts found." => "Keine Kontakte gefunden.",
"element name is not set." => "Kein Name für das Element angegeben.",
"Could not parse contact: " => "Konnte folgenden Kontakt nicht verarbeiten:",
"Cannot add empty property." => "Feld darf nicht leer sein.",
"At least one of the address fields has to be filled out." => "Mindestens eines der Adressfelder muss ausgefüllt werden.",
"Trying to add duplicate property: " => "Versuche doppelte Eigenschaft hinzuzufügen: ",
"Missing IM parameter." => "IM-Parameter fehlt.",
"Unknown IM: " => "IM unbekannt:",
"Information about vCard is incorrect. Please reload the page." => "Die Information der vCard ist fehlerhaft. Bitte aktualisiere die Seite.",
"Missing ID" => "Fehlende ID",
"Error parsing VCard for ID: \"" => "Fehler beim Einlesen der VCard für die ID: \"",
"checksum is not set." => "Keine Prüfsumme angegeben.",
"Information about vCard is incorrect. Please reload the page: " => "Die Informationen zur vCard sind fehlerhaft. Bitte Seite neu laden: ",
"Something went FUBAR. " => "Irgendwas ist hier so richtig schiefgelaufen. ",
"No contact ID was submitted." => "Es wurde keine Kontakt-ID übermittelt.",
"Error reading contact photo." => "Fehler beim Auslesen des Kontaktfotos.",
"Error saving temporary file." => "Fehler beim Speichern der temporären Datei.",
"The loading photo is not valid." => "Das Kontaktfoto ist fehlerhaft.",
"Contact ID is missing." => "Keine Kontakt-ID ist nicht angegeben.",
"No photo path was submitted." => "Kein Foto-Pfad angegeben.",
"File doesn't exist:" => "Datei existiert nicht: ",
"Error loading image." => "Fehler beim Laden des Bildes.",
"Error getting contact object." => "Fehler beim Abruf des Kontakt-Objektes.",
"Error getting PHOTO property." => "Fehler beim Abrufen der PHOTO-Eigenschaft.",
"Error saving contact." => "Fehler beim Speichern des Kontaktes.",
"Error resizing image" => "Fehler bei der Größenänderung des Bildes",
"Error cropping image" => "Fehler beim Zuschneiden des Bildes",
"Error creating temporary image" => "Fehler beim Erstellen des temporären Bildes",
"Error finding image: " => "Fehler beim Suchen des Bildes: ",
"Error uploading contacts to storage." => "Übertragen der Kontakte fehlgeschlagen.",
"There is no error, the file uploaded with success" => "Es ist kein Fehler aufgetreten. Die Datei wurde erfolgreich übertragen.",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Die Datei ist größer, als durch die upload_max_filesize Direktive in php.ini erlaubt",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Die Datei ist größer, als die MAX_FILE_SIZE Direktive erlaubt, die im HTML-Formular spezifiziert ist",
"The uploaded file was only partially uploaded" => "Die Datei konnte nur teilweise übertragen werden",
"No file was uploaded" => "Keine Datei konnte übertragen werden.",
"Missing a temporary folder" => "Kein temporärer Ordner vorhanden",
"Couldn't save temporary image: " => "Konnte das temporäre Bild nicht speichern:",
"Couldn't load temporary image: " => "Konnte das temporäre Bild nicht laden:",
"No file was uploaded. Unknown error" => "Keine Datei hochgeladen. Unbekannter Fehler",
"Contacts" => "Kontakte",
"Sorry, this functionality has not been implemented yet" => "Diese Funktion steht leider noch nicht zur Verfügung",
"Not implemented" => "Nicht verfügbar",
"Couldn't get a valid address." => "Konnte keine gültige Adresse abrufen.",
"Error" => "Fehler",
"Please enter an email address." => "Bitte gib Sie eine E-Mailadresse an.",
"Enter name" => "Name eingeben",
"Format custom, Short name, Full name, Reverse or Reverse with comma" => "Format benutzerdefiniert, Kurzname, voller Name, Rückwärts oder Rückwärts mit Komma",
"Select type" => "Wähle Typ",
"Select photo" => "Wähle  ein Foto",
"You do not have permission to add contacts to " => "Du besitzt nicht die erforderlichen Rechte, um Kontakte hinzuzufügen",
"Please select one of your own address books." => "Bitte wähle  eines Deiner Adressbücher aus.",
"Permission error" => "Berechtigungsfehler",
"Click to undo deletion of \"" => "Klicke  hier für die Wiederherstellung von \"",
"Cancelled deletion of: \"" => "Abbrechen des Löschens von: \"",
"This property has to be non-empty." => "Dieses Feld darf nicht leer sein.",
"Couldn't serialize elements." => "Konnte Elemente nicht serialisieren",
"Unknown error. Please check logs." => "Unbekannter Fehler. Bitte Logs überprüfen",
"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "'deleteProperty' wurde ohne Argumente aufgerufen. Bitte melde dies auf bugs.owncloud.org",
"Edit name" => "Name ändern",
"No files selected for upload." => "Keine Datei(en) zum Hochladen ausgewählt.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Die Datei, die Du hochladen möchtest, überschreitet die maximale Größe für Datei-Uploads auf diesem Server.",
"Error loading profile picture." => "Fehler beim Laden des Profilbildes.",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Einige zum Löschen vorgemerkte Kontakte wurden noch nicht gelöscht. Bitte warten.",
"Do you want to merge these address books?" => "Möchtest Du diese Adressbücher zusammenführen?",
"Shared by " => "Freigegeben von ",
"Upload too large" => "Die hochgeladene Datei ist zu groß",
"Only image files can be used as profile picture." => "Nur Bilder können als Profilbild genutzt werden.",
"Wrong file type" => "Falscher Dateityp",
"Your browser doesn't support AJAX upload. Please click on the profile picture to select a photo to upload." => "Der verwendete Browser unterstützt keinen Upload via AJAX. Bitte das Profilbild anklicken um ein Foto hochzuladen. ",
"Unable to upload your file as it is a directory or has 0 bytes" => "Deine Datei konnte nicht hochgeladen werden, weil es sich um einen Ordner handelt oder die Datei leer ist.",
"Upload Error" => "Fehler beim Hochladen",
"Pending" => "Ausstehend",
"Import done" => "Import ausgeführt",
"Not all files uploaded. Retrying..." => "Es wurden nicht alle Dateien hochgeladen. Versuche erneut...",
"Something went wrong with the upload, please retry." => "Beim Hochladen ist etwas schiefgegangen. Bitte versuche es erneut.",
"Importing..." => "Importiere...",
"The address book name cannot be empty." => "Der Name des Adressbuches darf nicht leer sein.",
"Result: " => "Ergebnis: ",
" imported, " => " importiert, ",
" failed." => " fehlgeschlagen.",
"Displayname cannot be empty." => "Der Anzeigename darf nicht leer sein.",
"Show CardDav link" => "CardDav-Link anzeigen",
"Show read-only VCF link" => "Schreibgeschützten VCF-Link anzeigen",
"Download" => "Herunterladen",
"Edit" => "Bearbeiten",
"Delete" => "Löschen",
"Cancel" => "Abbrechen",
"More..." => "Mehr...",
"Less..." => "Weniger...",
"You do not have the permissions to read this addressbook." => "Du besitzt keine Leseberechtigung für dieses Adressbuch.",
"You do not have the permissions to update this addressbook." => "Du verfügst nicht über die notwendigen Rechte, das Adressbuch zu aktualisieren.",
"There was an error updating the addressbook." => "Ein Fehler ist bei der Aktualisierung des Adressbuches aufgetreten.",
"You do not have the permissions to delete this addressbook." => "Du besitzt nicht die erforderlichen Rechte, dieses Adressbuch zu löschen.",
"There was an error deleting this addressbook." => "Beim Löschen des Adressbuches ist ein Fehler aufgetreten.",
"Addressbook not found: " => "Adressbuch nicht gefunden:",
"This is not your addressbook." => "Dies ist nicht Dein Adressbuch.",
"Contact could not be found." => "Kontakt konnte nicht gefunden werden.",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Arbeit",
"Home" => "Zuhause",
"Other" => "Andere",
"Mobile" => "Mobil",
"Text" => "Text",
"Voice" => "Anruf",
"Message" => "Mitteilung",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internet",
"Birthday" => "Geburtstag",
"Business" => "Geschäftlich",
"Call" => "Anruf",
"Clients" => "Kunden",
"Deliverer" => "Lieferant",
"Holidays" => "Feiertage",
"Ideas" => "Ideen",
"Journey" => "Reise",
"Jubilee" => "Jubiläum",
"Meeting" => "Besprechung",
"Personal" => "Persönlich",
"Projects" => "Projekte",
"Questions" => "Fragen",
"{name}'s Birthday" => "Geburtstag von {name}",
"Contact" => "Kontakt",
"You do not have the permissions to add contacts to this addressbook." => "Du besitzt nicht die erforderlichen Rechte, diesem Adressbuch Kontakte hinzuzufügen.",
"Could not find the vCard with ID." => "Die vCard mit der ID konnte nicht gefunden werden.",
"You do not have the permissions to edit this contact." => "Du besitzt nicht die erforderlichen Rechte, um diesen Kontakt zu bearbeiten.",
"Could not find the vCard with ID: " => "Die vCard mit der folgenden ID konnte nicht gefunden werden:",
"Could not find the Addressbook with ID: " => "Konnte das Adressbuch mit der folgenden ID nicht finden:",
"You do not have the permissions to delete this contact." => "Du besitzt nicht die erforderlichen Rechte, um diesen Kontakte zu löschen.",
"There was an error deleting this contact." => "Beim Löschen des Kontaktes ist ein Fehler aufgetreten.",
"Add Contact" => "Kontakt hinzufügen",
"Import" => "Importieren",
"Settings" => "Einstellungen",
"Close" => "Schließen",
"Keyboard shortcuts" => "Tastaturbefehle",
"Navigation" => "Navigation",
"Next contact in list" => "Nächster Kontakt aus der Liste",
"Previous contact in list" => "Vorheriger Kontakt aus der Liste",
"Expand/collapse current addressbook" => "Ausklappen / Einklappen des Adressbuches",
"Next addressbook" => "Nächstes Adressbuch",
"Previous addressbook" => "Vorheriges Adressbuch",
"Actions" => "Aktionen",
"Refresh contacts list" => "Kontaktliste neu laden",
"Add new contact" => "Neuen Kontakt hinzufügen",
"Add new addressbook" => "Neues Adressbuch hinzufügen",
"Delete current contact" => "Aktuellen Kontakt löschen",
"Drop photo to upload" => "Ziehe ein Foto hierher, um es hochzuladen",
"Delete current photo" => "Derzeitiges Foto löschen",
"Edit current photo" => "Derzeitiges Foto ändern",
"Upload new photo" => "Neues Foto hochladen",
"Select photo from ownCloud" => "Foto aus der ownCloud auswählen",
"Edit name details" => "Name ändern",
"Organization" => "Organisation",
"Nickname" => "Spitzname",
"Enter nickname" => "Spitzname angeben",
"Web site" => "Webseite",
"http://www.somesite.com" => "http://www.somesite.com",
"Go to web site" => "Webseite aufrufen",
"dd-mm-yyyy" => "dd.mm.yyyy",
"Groups" => "Gruppen",
"Separate groups with commas" => "Gruppen mit Komma getrennt",
"Edit groups" => "Gruppen editieren",
"Preferred" => "Bevorzugt",
"Please specify a valid email address." => "Bitte trage eine gültige E-Mail-Adresse ein.",
"Enter email address" => "E-Mail-Adresse angeben",
"Mail to address" => "E-Mail an diese Adresse schicken",
"Delete email address" => "E-Mail-Adresse löschen",
"Enter phone number" => "Telefonnummer angeben",
"Delete phone number" => "Telefonnummer löschen",
"Instant Messenger" => "Instant Messenger",
"Delete IM" => "IM löschen",
"View on map" => "Auf der Karte zeigen",
"Edit address details" => "Adressinformationen ändern",
"Add notes here." => "Füge hier Notizen ein.",
"Add field" => "Feld hinzufügen",
"Phone" => "Telefon",
"Email" => "E-Mail",
"Instant Messaging" => "Instant Messaging",
"Address" => "Adresse",
"Note" => "Notiz",
"Download contact" => "Kontakt herunterladen",
"Delete contact" => "Kontakt löschen",
"The temporary image has been removed from cache." => "Das temporäre Bild wurde aus dem Cache gelöscht.",
"Edit address" => "Adresse ändern",
"Type" => "Typ",
"PO Box" => "Postfach",
"Street address" => "Straßenanschrift",
"Street and number" => "Straße und Hausnummer",
"Extended" => "Erweitert",
"Apartment number etc." => "Wohnungsnummer usw.",
"City" => "Stadt",
"Region" => "Region",
"E.g. state or province" => "Z.B. Staat oder Bezirk",
"Zipcode" => "Postleitzahl",
"Postal code" => "Postleitzahl",
"Country" => "Land",
"Addressbook" => "Adressbuch",
"Hon. prefixes" => "Höflichkeitspräfixe",
"Miss" => "Frau",
"Ms" => "Frau",
"Mr" => "Herr",
"Sir" => "Herr",
"Mrs" => "Frau",
"Dr" => "Dr.",
"Given name" => "Vorname",
"Additional names" => "Zusätzliche Namen",
"Family name" => "Familienname",
"Hon. suffixes" => "Höflichkeitssuffixe",
"J.D." => "Dr. Jur.",
"M.D." => "Dr. med.",
"D.O." => "DGOM",
"D.C." => "MChiro",
"Ph.D." => "Dr.",
"Esq." => "Hochwohlgeborenen",
"Jr." => "Jr.",
"Sn." => "Sen.",
"Import a contacts file" => "Kontaktdatei importieren",
"Please choose the addressbook" => "Bitte Adressbuch auswählen",
"create a new addressbook" => "Neues Adressbuch erstellen",
"Name of new addressbook" => "Name des neuen Adressbuchs",
"Importing contacts" => "Kontakte werden importiert",
"<h3>You have no contacts in your addressbook.</h3><p>You can import VCF files by dragging them to the contacts list and either drop them on an addressbook to import into it, or on an empty spot to create a new addressbook and import into that.<br />You can also import by clicking on the import button at the bottom of the list.</p>" => "<h3>Du hast noch keine Kontaktdaten in Deinem Adressbuch.</h3><p>Du kannst VCF-Dateien importieren, indem Du diese herein ziehst und entweder \nauf einem bestehenden Adressbuch fallen lässt, um die Dateien in dieses Adressbuch zu importieren, oder auf einen freien Bereich, um ein neues Adressbuch anzulegen und die Dateien dort zu importieren.<br />Du kannst auch den Knopf 'Importieren' am Ende der Liste drücken.</p>",
"Add contact" => "Kontakt hinzufügen",
"Select Address Books" => "Wähle Adressbuch",
"Enter description" => "Beschreibung eingeben",
"CardDAV syncing addresses" => "CardDAV Sync-Adressen",
"more info" => "weitere Informationen",
"Primary address (Kontact et al)" => "Primäre Adresse (für Kontakt o.ä.)",
"iOS/OS X" => "iOS / OS X",
"Addressbooks" => "Adressbücher",
"Share" => "Teilen",
"New Address Book" => "Neues Adressbuch",
"Name" => "Name",
"Description" => "Beschreibung",
"Save" => "Speichern"
);
